<div align="center"><img src="https://gitee.com/cyrxdzj/PyCheer/raw/master/PyCheer/logo/logo.png" alt="logo"></div>
> 本项目正在开发中，敬请期待。

## 一，前言

`PyCheer` 是一个 `Python` 代码编辑器，基于 `flask`，支持在浏览器端（不一定要在同一台机器上，但必须互相联网）访问，为只用终端而没有桌面环境的服务器提供代码编辑帮助。同时也支持 `Markdown` 的编辑。

## 二，安装

请输入以下命令以安装：

```bash
pip install PyCheer
```

## 三，启动

进入对应目录后，请输入以下命令（二选一）启动：

```bash
pycheer run
python -m PyCheer run
```

此时，`PyCheer` 会输出一行蓝色字体（部分终端不支持颜色），代表 `Token`（在进入网页时需要使用），请复制下来。

使用浏览器访问：

```
http://localhost:1111
```

将 `Token` 粘贴进输入框里，即可开始使用 `PyCheer`。

对于没有复制功能的终端，请输入以下命令启动：

```bash
pycheer run -b
```

其中 `-b` 参数代表“自动启动浏览器”。

如果 `1111` 端口已被占用或你想同时启动多个 `PyCheer`，请加上 `-p <端口>` 参数以指定启动端口。

## 四，使用

#### 1，基本页面与操作

如图：

![启动图片](https://images.gitee.com/uploads/images/2021/0716/185205_f4052b51_7354699.png "屏幕截图.png")

其中，蓝色字体为 `Token`，前两个绿色字体为网页地址，但第二个可能无效。

然后在访问第一个网址，结果如图：

![目录图片](https://images.gitee.com/uploads/images/2021/0716/223428_4aba66e5_7354699.png "屏幕截图.png")

此时，您可以查看当前目录下的文件。

也可以访问 `localhost:<端口，默认为1111>` ，然后在如图输入框中输入 `Token`，点击“确定”。

![锁定页面图片](https://images.gitee.com/uploads/images/2021/0716/185603_1cd6f292_7354699.png "屏幕截图.png")

点击一个文件夹可以进入这个文件夹，点击一个文件可以打开或编辑这个文件。

目前支持编辑的文件：

|文件后缀|文件类型|
|:--:|:--:|
|`.py`|Python 源文件|
|`.html`|HTML 源文件|
|`.js`|JavaScript 源文件|
|`.css`|CSS 样式文件|
|`.md`|Markdown 文件|
|`.txt`|文本文档|

支持查看（但不支持编辑）的文件：

|文件后缀|文件类型|
|:--:|:--:|
|`.png`|PNG 图像文件|
|`.jpg`|JPG 图像文件|

对于其它类型的文件，默认以文本的方式展现在您的面前（但不可编辑）。如果这恰好不是文本，就会报 `500 Internal Server Error` 错误。

#### 2，退出

在右上角有一个“退出PyCheer”按钮，可以暂时退出（但不会关闭）`PyCheer`。再次输入 `Token` 即可再次进入 `PyCheer`。

#### 3，关闭

点击“关闭PyCheer”按钮即可关闭 `PyCheer` 服务。

#### 4，编辑文件

点击支持编辑的文件，即可进入编辑页面。

![编辑页面图片](https://images.gitee.com/uploads/images/2021/0716/203400_3140499c_7354699.png "屏幕截图.png")

如图，中间为代码编辑区，可以编辑代码。

下方为状态栏，指示当前状态。一旦代码被编辑，状态栏就会有所改变。

> `Markdown` 编辑器因技术原因是看不到状态栏的。

编辑完毕后，记得点击“保存”！

#### 5，新建文件（夹）

在目录页面中点击“新建文件（夹）”按钮，即可新建文件（夹）。

#### 6，重命名文件

点击目录页面中文件名右边的图标，即可进行重命名。